@@ -3,15 +3,10 @@
 
 /* camel-exchange-store.h: class for a exchange store */
 
-
 #ifndef CAMEL_EXCHANGE_STORE_H
 #define CAMEL_EXCHANGE_STORE_H 1
 
-
-#ifdef __cplusplus
-extern "C" {
-#pragma }
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #include <camel/camel-store.h>
 #include <camel/camel-offline-store.h>
@@ -41,14 +36,11 @@ typedef struct {
 
 } CamelExchangeStoreClass;
 
-
 /* Standard Camel function */
 CamelType camel_exchange_store_get_type (void);
 
 gboolean camel_exchange_store_connected (CamelExchangeStore *store, CamelException *ex);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif /* CAMEL_EXCHANGE_STORE_H */
